@@ -1,24 +1,7 @@
-/*
- * Copyright (C) 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     wangchunlin<wangchunlin@uniontech.com>
- *
- * Maintainer: wangchunlin<wangchunlin@uniontech.com>
- *             houchengqiu<houchengqiu@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef EXHIBITIONWIDGET_H
 #define EXHIBITIONWIDGET_H
 
@@ -28,12 +11,16 @@
 
 #include <QScopedPointer>
 
-class ExhibitionWidgetPrivate;
-class MatchWidget;
-class PreviewWidget;
 class QHBoxLayout;
 class QVBoxLayout;
 class QPushButton;
+
+namespace GrandSearch {
+
+class ExhibitionWidgetPrivate;
+class MatchWidget;
+class PreviewWidget;
+
 class ExhibitionWidget : public Dtk::Widget::DWidget
 {
     Q_OBJECT
@@ -48,12 +35,12 @@ public slots:
     void onSelectPreviousItem();
     void onHandleItem();
 
-    void appendMatchedData(const GrandSearch::MatchedItemMap &matchedData);//追加显示匹配数据
+    void appendMatchedData(const MatchedItemMap &matchedData);//追加显示匹配数据
     void onSearchCompleted();
-    void previewItem(const QString &searchGroupName, const GrandSearch::MatchedItem &item);
+    void previewItem(const QString &searchGroupName, const MatchedItem &item);
 
 signals:
-    void sigCurrentItemChanged(const QString &searchGroupName, const GrandSearch::MatchedItem &item);
+    void sigCurrentItemChanged(const QString &searchGroupName, const MatchedItem &item);
     void sigShowNoContent(bool noContent);
     void sigCloseWindow();
     void sigPreviewStateChanged(bool priview);
@@ -76,4 +63,6 @@ private:
     PreviewWidget *m_previewWidget = nullptr;
 };
 
+}
+
 #endif // EXHIBITIONWIDGET_H
