@@ -1,384 +1,427 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="pl">
 <context>
-    <name>AudioPreviewPlugin</name>
+    <name>GrandSearch::BestMatchWidget</name>
     <message>
-        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="71"/>
-        <source>Artist:</source>
-        <translation>Wykonawca:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="83"/>
-        <source>Album:</source>
-        <translation>Album:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="108"/>
-        <source>Duration:</source>
-        <translation>Czas trwania:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="123"/>
-        <source>Type:</source>
-        <translation>Typ:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="135"/>
-        <source>Location:</source>
-        <translation>Położenie:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="149"/>
-        <source>Time modified:</source>
-        <translation>Data modyfikacji:</translation>
-    </message>
-</context>
-<context>
-    <name>BestMatchWidget</name>
-    <message>
-        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="38"/>
+        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="22"/>
         <source>Best match</source>
-        <translation type="unfinished"/>
+        <translation>Najlepsze dopasowanie</translation>
     </message>
 </context>
 <context>
-    <name>CustomWidget</name>
+    <name>GrandSearch::BlackListWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="42"/>
+        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="26"/>
+        <source>Excluded path</source>
+        <translation>Wykluczona ścieżka</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="37"/>
+        <source>Add paths to the exclusion list to prevent searching in them.</source>
+        <translation>Dodaj ścieżki do listy wykluczeń, aby pominąć je podczas wyszukiwania.</translation>
+    </message>
+</context>
+<context>
+    <name>GrandSearch::CustomWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="26"/>
         <source>Custom search</source>
         <translation>Wyszukiwanie niestandardowe</translation>
     </message>
 </context>
 <context>
-    <name>DdeGrandSearchDockPlugin</name>
+    <name>GrandSearch::DdeGrandSearchDockPlugin</name>
     <message>
-        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="57"/>
-        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="100"/>
+        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="42"/>
+        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="85"/>
         <source>Grand Search</source>
         <translation>Wyszukiwarka</translation>
     </message>
     <message>
-        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="163"/>
+        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="148"/>
         <source>Search settings</source>
         <translation>Ustawienia wyszukiwania</translation>
     </message>
 </context>
 <context>
-    <name>EntranceWidget</name>
+    <name>GrandSearch::DeleteDialog</name>
     <message>
-        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="241"/>
+        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="14"/>
+        <source>Do you want to remove the path from the exclusion list?</source>
+        <translation>Czy chcesz usunąć ścieżkę z listy wykluczeń?</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="20"/>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>Anuluj</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="28"/>
+        <source>Confirm</source>
+        <comment>button</comment>
+        <translation>Potwierdź</translation>
+    </message>
+</context>
+<context>
+    <name>GrandSearch::EntranceWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="225"/>
         <source>Search</source>
         <translation>Szukaj</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="242"/>
+        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="226"/>
         <source>What would you like to search for?</source>
         <translation>Co chciałbyś wyszukać?</translation>
     </message>
 </context>
 <context>
-    <name>EntranceWidgetPrivate</name>
+    <name>GrandSearch::EntranceWidgetPrivate</name>
     <message>
-        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="94"/>
+        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="78"/>
         <source>Cut</source>
         <translation>Wytnij</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="98"/>
+        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="82"/>
         <source>Copy</source>
         <translation>Kopiuj</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="102"/>
+        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="86"/>
         <source>Paste</source>
         <translation>Wklej</translation>
     </message>
 </context>
 <context>
-    <name>GeneralPreviewPlugin</name>
+    <name>GrandSearch::GeneralPreviewPlugin</name>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="208"/>
+        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="192"/>
         <source>Location:</source>
         <translation>Położenie:</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="219"/>
+        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="203"/>
         <source>Time modified:</source>
         <translation>Data modyfikacji:</translation>
     </message>
 </context>
 <context>
-    <name>GeneralToolBar</name>
+    <name>GrandSearch::GeneralToolBar</name>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="85"/>
+        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="70"/>
         <source>Open</source>
         <translation>Otwórz</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="90"/>
+        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="75"/>
         <source>Open Path</source>
         <translation>Otwórz ścieżkę</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="95"/>
+        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="80"/>
         <source>Copy Path</source>
         <translation>Kopiuj ścieżkę</translation>
     </message>
 </context>
 <context>
-    <name>GroupWidget</name>
+    <name>GrandSearch::GroupWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="260"/>
+        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="244"/>
         <source>More</source>
         <translation>Więcej</translation>
     </message>
 </context>
 <context>
-    <name>ImagePreviewPlugin</name>
+    <name>GrandSearch::IndexWidget</name>
     <message>
-        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="67"/>
-        <source>Dimensions:</source>
-        <translation>Wymiary:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="83"/>
-        <source>Type:</source>
-        <translation>Typ:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="98"/>
-        <source>Size:</source>
-        <translation>Rozmiar:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
-        <source>Location:</source>
-        <translation>Położenie:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="124"/>
-        <source>Time modified:</source>
-        <translation>Data modyfikacji:</translation>
+        <location filename="../src/grand-search/gui/searchconfig/indexwidget.cpp" line="22"/>
+        <source>Index</source>
+        <translation>Indeks</translation>
     </message>
 </context>
 <context>
-    <name>MainWindow</name>
+    <name>GrandSearch::MainWindow</name>
     <message>
-        <location filename="../src/grand-search/gui/mainwindow.cpp" line="224"/>
+        <location filename="../src/grand-search/gui/mainwindow.cpp" line="208"/>
         <source>No search results</source>
         <translation>Brak wyników wyszukiwania</translation>
     </message>
 </context>
 <context>
-    <name>PlanWidget</name>
+    <name>GrandSearch::PlanWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="43"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="27"/>
         <source>Search experience program</source>
         <translation>Program doświadczeń wyników wyszukiwania</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="51"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="35"/>
         <source>Join search experience program</source>
         <translation>Dołącz do programu doświadczeń wyszukiwania</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="48"/>
         <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
         <translation>Przystąpienie do programu wyszukiwania oznacza, że udzielasz zgodę i upoważniasz nas do gromadzenia informacji o Twoim urządzeniu, systemie, ikonach, treści, właściwościach, aplikacjach i ich ustawieniach. Jeśli nie zgadzasz się na gromadzenie i wykorzystywanie wyżej wymienionych informacji, nie dołączaj do programu.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="57"/>
         <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
         <translation>Aby dowiedzieć się więcej w jaki sposób twoje dane są zarządzane, zapoznaj się z Polityką prywatności oprogramowania UnionTech (</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="75"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="59"/>
         <source>https://www.uniontech.com/agreement/privacy-en</source>
         <translation>https://www.uniontech.com/agreement/privacy-en</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="60"/>
         <source>https://www.deepin.org/en/agreement/privacy/</source>
         <translation>https://www.deepin.org/en/agreement/privacy/</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="78"/>
+        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="62"/>
         <source>).</source>
         <translation>).</translation>
     </message>
 </context>
 <context>
-    <name>QObject</name>
+    <name>GrandSearch::ScopeWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="41"/>
-        <source>Best match</source>
-        <translation>Najlepsze dopasowanie</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
-        <source>Applications</source>
-        <translation>Programy</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="43"/>
-        <source>Settings</source>
-        <translation>Ustawienia</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="44"/>
-        <source>Videos</source>
-        <translation>Filmy</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="45"/>
-        <source>Music</source>
-        <translation>Muzyka</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="46"/>
-        <source>Pictures</source>
-        <translation>Zdjęcia</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="47"/>
-        <source>Documents</source>
-        <translation>Dokumenty</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="48"/>
-        <source>Folders</source>
-        <translation>Katalog</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="49"/>
-        <source>Files</source>
-        <translation>Pliki</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="50"/>
-        <source>Web</source>
-        <translation>Internet</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="38"/>
-        <source>Dimensions:</source>
-        <translation>Wymiary:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="39"/>
-        <source>Type:</source>
-        <translation>Typ:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="40"/>
-        <source>Size:</source>
-        <translation>Rozmiar:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="41"/>
-        <source>Duration:</source>
-        <translation>Czas trwania:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="42"/>
-        <source>Location:</source>
-        <translation>Położenie:</translation>
-    </message>
-    <message>
-        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="43"/>
-        <source>Time modified:</source>
-        <translation>Data modyfikacji:</translation>
-    </message>
-    <message>
-        <location filename="../src/grand-search-daemon/searcher/file/filesearchutils.cpp" line="215"/>
-        <source>modified</source>
-        <translation>zmodyfikowany</translation>
-    </message>
-</context>
-<context>
-    <name>ScopeWidget</name>
-    <message>
-        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="44"/>
+        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="28"/>
         <source>Search contents</source>
         <translation>Przeszukaj zawartość</translation>
     </message>
 </context>
 <context>
-    <name>SearchEngineWidget</name>
+    <name>GrandSearch::SearchEngineWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="48"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="31"/>
         <source>Default search engine</source>
-        <translation type="unfinished"/>
+        <translation>Domyślna wyszukiwarka</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="56"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="39"/>
         <source>Search for keywords by the default search engine.</source>
-        <translation type="unfinished"/>
+        <translation>Szukaj słów kluczowych przy użyciu domyślnej wyszukiwarki.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="55"/>
         <source>Default search engine is</source>
-        <translation type="unfinished"/>
+        <translation>Domyślna wyszukiwarka to</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="81"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="64"/>
         <source>Google</source>
-        <translation type="unfinished"/>
+        <translation>Google</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="82"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="65"/>
         <source>Baidu</source>
-        <translation type="unfinished"/>
+        <translation>Baidu</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="83"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="66"/>
         <source>Bing</source>
-        <translation type="unfinished"/>
+        <translation>Bing</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="84"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="67"/>
         <source>Yahoo</source>
-        <translation type="unfinished"/>
+        <translation>Yahoo</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="85"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="68"/>
         <source>360</source>
-        <translation type="unfinished"/>
+        <translation>360</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="86"/>
+        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="69"/>
         <source>Sogou</source>
-        <translation type="unfinished"/>
+        <translation>Sogou</translation>
     </message>
 </context>
 <context>
-    <name>StaticTextWorker</name>
+    <name>GrandSearch::StaticTextWorker</name>
     <message>
-        <location filename="../src/grand-search-daemon/searcher/web/statictextworker.cpp" line="67"/>
+        <location filename="../src/libgrand-search-daemon/searcher/web/statictextworker.cpp" line="53"/>
         <source>Search for &quot;%1&quot;</source>
-        <translation type="unfinished"/>
+        <translation>Wyszukaj &quot;%1&quot;</translation>
     </message>
 </context>
 <context>
-    <name>TailerWidget</name>
+    <name>GrandSearch::TailerWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="33"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="18"/>
         <source>Tailer settings</source>
         <translation>Ustawienia formatowania</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="28"/>
         <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
         <translation>Jest to wyświetlane pod koniec wyników wyszukiwania dla lepszej identyfikacji i rozróżnienia przedmiotów z taką samą nazwą.</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="56"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="41"/>
         <source>Parent directory</source>
         <translation>Katalog nadrzędny</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="58"/>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
         <source>Time modified</source>
         <translation>Data modyfikacji</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>GrandSearch::audio_preview::AudioPreviewPlugin</name>
+    <message>
+        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="52"/>
+        <source>Artist:</source>
+        <translation>Wykonawca:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="64"/>
+        <source>Album:</source>
+        <translation>Album:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="85"/>
+        <source>Duration:</source>
+        <translation>Czas trwania:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="100"/>
+        <source>Type:</source>
+        <translation>Typ:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="112"/>
+        <source>Location:</source>
+        <translation>Położenie:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="126"/>
+        <source>Time modified:</source>
+        <translation>Data modyfikacji:</translation>
+    </message>
+</context>
+<context>
+    <name>GrandSearch::image_preview::ImagePreviewPlugin</name>
+    <message>
+        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="53"/>
+        <source>Dimensions:</source>
+        <translation>Wymiary:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="69"/>
+        <source>Type:</source>
+        <translation>Typ:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="84"/>
+        <source>Size:</source>
+        <translation>Rozmiar:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="96"/>
+        <source>Location:</source>
+        <translation>Położenie:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
+        <source>Time modified:</source>
+        <translation>Data modyfikacji:</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="24"/>
+        <source>Best match</source>
+        <translation>Najlepsze dopasowanie</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="25"/>
+        <source>Applications</source>
+        <translation>Programy</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="26"/>
+        <source>Settings</source>
+        <translation>Ustawienia</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="27"/>
+        <source>Videos</source>
+        <translation>Filmy</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="28"/>
+        <source>Music</source>
+        <translation>Muzyka</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="29"/>
+        <source>Pictures</source>
+        <translation>Zdjęcia</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="30"/>
+        <source>Documents</source>
+        <translation>Dokumenty</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="31"/>
+        <source>Folders</source>
+        <translation>Katalogi</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="32"/>
+        <source>Files</source>
+        <translation>Pliki</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="33"/>
+        <source>Web</source>
+        <translation>Internet</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="19"/>
+        <source>Dimensions:</source>
+        <translation>Wymiary:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="20"/>
+        <source>Type:</source>
+        <translation>Typ:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="21"/>
+        <source>Size:</source>
+        <translation>Rozmiar:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="22"/>
+        <source>Duration:</source>
+        <translation>Czas trwania:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="23"/>
+        <source>Location:</source>
+        <translation>Położenie:</translation>
+    </message>
+    <message>
+        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="24"/>
+        <source>Time modified:</source>
+        <translation>Data modyfikacji:</translation>
+    </message>
+    <message>
+        <location filename="../src/libgrand-search-daemon/searcher/file/filesearchutils.cpp" line="203"/>
+        <source>modified</source>
+        <translation>zmodyfikowany</translation>
+    </message>
+</context>
+</TS>
